use reqwest::Method;
use serde::{Serialize, Deserialize};

use crate::types::{ElementId, PotId};

use super::UbisyncRequest;

#[derive(Serialize, Deserialize, Debug, Clone)]
pub enum AppEvent {
    NewPot {
        id: PotId,
        app_type: String,
    },
    ElementUpdate {
        id: ElementId,
    }
}

#[derive(Serialize, Deserialize, Debug, Clone)]
pub struct PollEventsRequest {
    pub timeout: u16,
    pub accumulate: u16,
}

#[derive(Serialize, Deserialize, Debug, Clone)]
pub struct PollEventsResponse {
    pub events: Vec<AppEvent>,
}


impl UbisyncRequest for PollEventsRequest {
    type PathParameters = ();
    type Response = PollEventsResponse;

    fn method(&self) -> reqwest::Method {
        Method::GET
    }

    fn path(&self, _: Self::PathParameters) -> String {
        "/events".to_string()
    }
}